=====
About
=====

Lcapy was developed by Michael Hayes as a holiday programming
exercise.  Michael is a professor in the Department of Electrical and
Computer Engineering at the University of Canterbury, New Zealand.  He
is also an amateur musician and loves to wander around the hills.  And
no, he does not teach circuit theory papers.

Originally, Lcapy was developed for modelling piezoelectric
transducers and then it grew...  Along the way, Michael has been
assisted by some of his postgraduate students who like to find bugs.
A special thanks to Matthew Edwards for dragging the continuous
improvement into the twenty-first century and to Juergen Weizenecker
for his work on Z-transforms, DTFTs, and DFTs.

If you wish to help with the development or documentation you are most
welcome.


Citation
========


To cite Lcapy in publications use

Hayes M. 2022. Lcapy: symbolic linear circuit analysis with Python. PeerJ Computer Science 8:e875 https://doi.org/10.7717/peerj-cs.875

A BibTeX entry for LaTeX users is

.. code-block:: none

   @article{10.7717/peerj-cs.875,
    title = {Lcapy: symbolic linear circuit analysis with {Python}},
    author = {Hayes, Michael},
    year = 2022,
    month = Feb,
    keywords = {Linear circuit analysis, symbolic computation, Python},
    pages = {e875},
    journal = {PeerJ Computer Science},
    issn = {2376-5992},
    url = {https://doi.org/10.7717/peerj-cs.875},
    doi = {10.7717/peerj-cs.875}
   }



Contributors
============

Michael Hayes

Matthew Edwards

Blair Bonnett

Juergen Weizenecker
